package com.xy.config;

import com.dtp.core.support.DynamicTp;
import com.xy.error.CommRuntimeException;
import com.xy.utils.ThreadPoolUtils;
import org.springframework.context.annotation.Bean;
import org.springframework.scheduling.concurrent.ThreadPoolTaskExecutor;
import org.springframework.stereotype.Component;

@Component
public class DeviceThreadPoolConfig {

    public static final String DEVICE_COMMON_POLL = "deviceCommonPoll";

    public static final String DATA_POLL = "dataPoll";

    /**
     * 公用线程池
     */
    @DynamicTp
    @Bean(DEVICE_COMMON_POLL)
    public ThreadPoolTaskExecutor deviceCommonPoll() {
        int coreSize = 5;
        return ThreadPoolUtils.newPoll()
                .name(DEVICE_COMMON_POLL)
                .coreSize(coreSize)
                .maxSize(coreSize * 2)
                .keepAlive(60)
                .queueSize(coreSize * 10)
                .builder();
    }

    /**
     * 统计mqtt消费线程池
     */
    @DynamicTp
    @Bean(DATA_POLL)
    public ThreadPoolTaskExecutor orderData() {
        int coreSize = 5;
        return ThreadPoolUtils.newPoll()
                .name(DATA_POLL)
                .coreSize(coreSize)
                .maxSize(coreSize * 2)
                .keepAlive(60)
                .queueSize(coreSize * 10)
                .rejected((r, executor) -> {
                    throw new CommRuntimeException("统计消费者线程池已满");
                })
                .builder();
    }

}
